package com.evobms.project.system.service;

import java.util.List;
import com.evobms.project.system.domain.BmsDevices;

/**
 * BBOX管理Service接口
 *
 * @author 田志阳
 * @date 2025-10-10
 */
public interface IBmsDevicesService
{
    /**
     * 查询BBOX管理
     *
     * @param id BBOX管理主键
     * @return BBOX管理
     */
    public BmsDevices selectBmsDevicesById(String id);

    /**
     * 查询BBOX管理列表
     *
     * @param bmsDevices BBOX管理
     * @return BBOX管理集合
     */
    public List<BmsDevices> selectBmsDevicesList(BmsDevices bmsDevices);

    /**
     * 新增BBOX管理
     *
     * @param bmsDevices BBOX管理
     * @return 结果
     */
    public int insertBmsDevices(BmsDevices bmsDevices);

    /**
     * 修改BBOX管理
     *
     * @param bmsDevices BBOX管理
     * @return 结果
     */
    public int updateBmsDevices(BmsDevices bmsDevices);

    /**
     * 批量删除BBOX管理
     *
     * @param ids 需要删除的BBOX管理主键集合
     * @return 结果
     */
    public int deleteBmsDevicesByIds(String[] ids);

    /**
     * 删除BBOX管理信息
     *
     * @param id BBOX管理主键
     * @return 结果
     */
    public int deleteBmsDevicesById(String id);

    BmsDevices selectBmsDevicesBySn(String deviceSn);

    BmsDevices selectBmsDevicesList1(BmsDevices query);
}
